@@ -350,7 +350,7 @@ class Migration(SchemaMigration):
             'help_text': ('django.db.models.fields.CharField', [], {'max_length': '200', 'blank': 'True'}),
             'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
             'label': ('django.db.models.fields.CharField', [], {'max_length': '2000'}),
-            'position': ('django.db.models.fields.IntegerField', [], {'blank': 'True'}),
+            'position': ('django.db.models.fields.IntegerField', [], {'default': '0', 'null': 'True', 'blank': 'True'}),
             'required': ('django.db.models.fields.BooleanField', [], {'default': 'False'}),
             'unique': ('django.db.models.fields.BooleanField', [], {'default': 'False'}),
             'visible': ('django.db.models.fields.BooleanField', [], {'default': 'True'}),
@@ -609,12 +609,12 @@ class Migration(SchemaMigration):
             'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
             'name': ('django.db.models.fields.CharField', [], {'unique': 'True', 'max_length': '255'}),
             'never_expires': ('django.db.models.fields.BooleanField', [], {'default': 'False'}),
-            'order': ('django.db.models.fields.IntegerField', [], {'default': '0'}),
             'owner': ('django.db.models.fields.related.ForeignKey', [], {'default': 'None', 'related_name': "'memberships_membershiptype_owner'", 'null': 'True', 'to': "orm['auth.User']"}),
             'owner_username': ('django.db.models.fields.CharField', [], {'max_length': '50'}),
             'period': ('django.db.models.fields.IntegerField', [], {'default': '0'}),
             'period_type': ('django.db.models.fields.CharField', [], {'default': "'rolling'", 'max_length': '10'}),
             'period_unit': ('django.db.models.fields.CharField', [], {'max_length': '10'}),
+            'position': ('django.db.models.fields.IntegerField', [], {'default': '0', 'null': 'True', 'blank': 'True'}),
             'price': ('django.db.models.fields.DecimalField', [], {'default': '0', 'max_digits': '15', 'decimal_places': '2', 'blank': 'True'}),
             'renewal': ('django.db.models.fields.BooleanField', [], {'default': 'False'}),
             'renewal_period_end': ('django.db.models.fields.IntegerField', [], {'default': '30'}),
